/*  
 *  xconvers - GTK+ client for amateur radio convers
 *  Copyright (C) 2000-2001 Joop Stakenborg <pa4tu@amsat.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * utils.h
 */

void widget_visible(gchar *name, gboolean state);
gboolean remove_calls(gchar *key, gpointer value, gpointer user_data);
void set_icon(GtkWidget *dialog, gchar *name);
void set_title(GtkWidget *dialog, gchar *format);
void updatestatusbar(GString *statusmessage);